This directory contains examples, categorized as follows:

- **[Notebooks](notebooks/)** demonstrate the usage of EvoTorch on various problems, and serve as tutorials to the interested reader.
- **[Scripts](scripts/)** serve as directly executable examples for quickly observing the basic usage of EvoTorch, and as starting points for new experiments.
